// Copyright (c) 2024 mStar
//
// Licensed under the EUPL, Version 1.2
//
// You may not use this work except in compliance with the Licence.
// You should have received a copy of the Licence along with this work. If not, see:
// <https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12>.
// See the Licence for the specific language governing permissions and limitations under the Licence.
//

package storage

import (
	"crypto/rsa"
	"net/mail"
	"net/url"

	"gorm.io/gorm"
)

type personDB struct {
	gorm.Model // Includes primary key (uid) as well as various time info

	// Public data

	uid       string
	name      string
	instance  url.URL
	local     bool
	publicKey string

	// Private data, set if local == true

	mail       *mail.Address
	pwHash     *string
	inbox      url.URL
	privateKey *rsa.PrivateKey
	following  []url.URL
	followers  []url.URL
}

type noteDB struct {
	gorm.Model // Includes primary key (uid) as well as various time info

	// Public data

	uid       string
	content   string
	creator   url.URL
	instance  url.URL
	local     bool
	tags      []string
	repliesTo *url.URL
	deliverTo []url.URL

	// Private data

	// None yet
}
